@@ -7,7 +7,8 @@
 """
 from __future__ import with_statement
 from django.db import models
-from noc.sa.models import ManagedObject
+from noc.sa.models import ManagedObject,ManagedObjectSelector
+from noc.main.models import TimePattern,NotificationGroup
 from noc.settings import config
 from noc.lib.fileutils import safe_rewrite
 from noc.fm.triggers import event_trigger_registry
@@ -46,6 +47,8 @@ class MIBNotFoundException(Exception):
 ##
 rx_module_not_found=re.compile(r"{module-not-found}.*`([^']+)'")
 rx_py_id=re.compile("[^0-9a-zA-Z]+")
+rx_mibentry=re.compile(r"^((\d+\.){5,}\d+)|(\S+::\S+)$")
+rx_mib_name=re.compile(r"^(\S+::\S+?)(.\d+)?$")
 
 ##
 ## SNMP MIB
@@ -173,6 +176,36 @@ class MIB(models.Model):
             except MIBData.DoesNotExist:
                 rest.append(l_oid.pop())
         return oid
+    ##
+    ## Returns description for symbolic/OID string
+    ##
+    @classmethod
+    def get_description(self,v):
+        if not rx_mibentry.match(v):
+            return ""
+        if "::" in v:
+            # MIB::name
+            match=rx_mib_name.match(v)
+            if not match:
+                return ""
+            try:
+                d=MIBData.objects.get(name=match.group(1))
+                return d.description
+            except MIBData.DoesNotExist:
+                return ""
+        else:
+            # Pure OID
+            try:
+                d=MIBData.objects.get(oid=v)
+                return d.description
+            except MIBData.DoesNotExist:
+                pass
+            try:
+                d=MIBData.objects.get(oid=".".join((v.split(".")[:-1])))
+                return d.description
+            except MIBData.DoesNotExist:
+                return ""
+            
 ##
 ## MIB elements
 ##
@@ -400,15 +433,18 @@ class EventPostProcessingRule(models.Model):
     class Meta:
         verbose_name="Event Post-Processing Rule"
         verbose_name_plural="Event Post-Processing Rules"
-    event_class=models.ForeignKey(EventClass,verbose_name="Event Class")
     name=models.CharField("Name",max_length=64)
     preference=models.IntegerField("Preference",default=1000)
     is_active=models.BooleanField("Is Active",default=True)
+    event_class=models.ForeignKey(EventClass,verbose_name="Event Class")
     description=models.TextField("Description",blank=True,null=True)
+    managed_object_selector=models.ForeignKey(ManagedObjectSelector,verbose_name="Managed Object Selector",null=True,blank=True)
+    time_pattern=models.ForeignKey(TimePattern,verbose_name="Time Pattern",null=True,blank=True)
     # Actions
     change_priority=models.ForeignKey(EventPriority,verbose_name="Change Priority to",blank=True,null=True)
     change_category=models.ForeignKey(EventCategory,verbose_name="Change Category to",blank=True,null=True)
     action=models.CharField("Action",max_length=1,choices=[("A","Make Active"),("C","Close"),("D","Drop")],default="A")
+    notification_group=models.ForeignKey(NotificationGroup,verbose_name="Notification Group",null=True,blank=True)
     def __unicode__(self):
         return self.name
 ##
@@ -571,6 +607,15 @@ class EventData(models.Model):
     key=models.CharField("Key",max_length=256)
     value=models.TextField("Value",blank=True,null=True)
     type=models.CharField("Type",max_length=1,choices=[(">","Received"),("V","Variable"),("R","Resolved")],default=">")
+    ##
+    ## Resolve MIBs in key/value part and fill out hint
+    ##
+    def _description(self):
+        d=MIB.get_description(self.value)
+        if d:
+            return d
+        return MIB.get_description(self.key)
+    description=property(_description)
 ##
 ## Repeated events are deleated from Event table and only short record in EventRepeat remains
 ##
