@@ -5,7 +5,7 @@
 ## Copyright (C) 2007-2009 The NOC Project
 ## See LICENSE for details
 ##----------------------------------------------------------------------
-import socket,select,errno,time,logging,pty,os,signal
+import socket,select,errno,time,logging,pty,os,signal,subprocess
 from errno import EALREADY, EINPROGRESS, EWOULDBLOCK, ECONNRESET, \
      ENOTCONN, ESHUTDOWN, EINTR, EISCONN, ECONNREFUSED, EPIPE, errorcode
 from noc.lib.debug import error_report
@@ -25,10 +25,10 @@ class Socket(object):
         self.factory=factory
         self.socket=sock
         self.socket.setblocking(0)
-        self.factory.register_socket(self)
-        self.name=None
         self.start_time=time.time()
         self.last_read=self.start_time+100
+        self.factory.register_socket(self)
+        self.name=None
     
     def can_read(self):
         return True
@@ -333,6 +333,33 @@ class ConnectedTCPSSLSocket(ConnectedTCPSocket):
                     return
                 raise
 ##
+## UDP send/receive socket
+##
+class UDPSocket(Socket):
+    def __init__(self,factory):
+        self.out_buffer=[]
+        super(UDPSocket,self).__init__(factory,socket.socket(socket.AF_INET,socket.SOCK_DGRAM))
+    
+    def can_write(self):
+        return self.out_buffer
+    
+    def handle_write(self):
+        msg,addr=self.out_buffer.pop(0)
+        self.socket.sendto(msg,addr)
+
+    def handle_read(self):
+        msg,transport_address=self.socket.recvfrom(8192)
+        if msg=="":
+            return
+        self.on_read(msg,transport_address[0],transport_address[1])
+    
+    def on_read(self,data,address,port):
+        pass
+
+    def sendto(self,msg,addr):
+        self.out_buffer+=[(msg,addr)]
+    
+##
 ## File wrapper to mimic behavior of socket
 ##
 class FileWrapper(object):
@@ -368,7 +395,7 @@ class PTYSocket(Socket):
         if self.pid==0:
             os.execv(argv[0],argv)
         else:
-            Socket.__init__(self,factory,FileWrapper(fd))
+            super(PTYSocket,self).__init__(factory,FileWrapper(fd))
             
     def handle_read(self):
         try:
@@ -414,7 +441,31 @@ class PTYSocket(Socket):
     
     def on_read(self,data):
         pass
+##
+## PopenSocket
+## Events: on_read, on_close
+##
+class PopenSocket(Socket):
+    def __init__(self,factory,argv):
+        self.debug("Launching %s"%argv)
+        self.p=subprocess.Popen(argv,stdout=subprocess.PIPE)
+        super(PopenSocket,self).__init__(factory,FileWrapper(self.p.stdout.fileno()))
+        self.update_status()
 
+    def handle_read(self):
+        try:
+            data=self.socket.read(8192)
+        except OSError:
+            self.close()
+            return
+        self.update_status()
+        if data:
+            self.on_read(data)
+        else:
+            self.close()
+
+    def close(self):
+        Socket.close(self)
 ##
 ## Socket Factory.
 ## Methods:
