@@ -42,21 +42,29 @@ class DaemonData(object):
     ##
     def launch(self):
         logging.info("Launching %s"%self.name)
-        pid=os.fork()
+        try:
+            pid=os.fork()
+        except OSError, e:
+            logging.error("%s: Fork failed: %s(%s)"%(self.name,e.strerror,e.errno))
+            return
         if pid:
             self.pid=pid
             logging.info("Daemon %s started as PID %d"%(self.name,self.pid))
         else:
             # Run child
-            if self.group:
-                os.setgid(self.gid)
-                os.setegid(self.gid)
-            if self.user:
-                os.setuid(self.uid)
-                os.seteuid(self.uid)
-                # Set up EGG Cache to prevent permissions problem
-                os.environ["PYTHON_EGG_CACHE"]="/tmp/.egg-cache%d"%self.uid
-            os.execv(sys.executable,[sys.executable,"./scripts/%s.py"%self.name,"launch"])
+            try:
+                if self.group:
+                    os.setgid(self.gid)
+                    os.setegid(self.gid)
+                if self.user:
+                    os.setuid(self.uid)
+                    os.seteuid(self.uid)
+                    # Set up EGG Cache to prevent permissions problem in python 2.6
+                    os.environ["PYTHON_EGG_CACHE"]="/tmp/.egg-cache%d"%self.uid
+                os.execv(sys.executable,[sys.executable,"./scripts/%s.py"%self.name,"launch"])
+            except OSError, e:
+                logging.error("%s: OS Error: %s(%s)"%(self.name,e.strerror,e.errno))
+                sys.exit(1)
 
 class Launcher(Daemon):
     daemon_name="noc-launcher"
@@ -66,7 +74,7 @@ class Launcher(Daemon):
         gids={}
         uids={}
         is_superuser=os.getuid()==0
-        for n in ["fcgi","sae","activator","classifier","correlator","notifier"]:
+        for n in ["fcgi","sae","activator","classifier","correlator","notifier","probe"]:
             dn="noc-%s"%n
             is_enabled=self.config.getboolean(dn,"enabled")
             # Resolve group name
