@@ -15,3 +15,7 @@ from noc.sa.interfaces.igetdot11associations import IGetDot11Associations
 from noc.sa.interfaces.iping import IPing
 from noc.sa.interfaces.igetarp import IGetARP
 from noc.sa.interfaces.icommands import ICommands
+from noc.sa.interfaces.igetdhcpbinding import IGetDHCPBinding
+# User Management
+from noc.sa.interfaces.igetlocalusers import IGetLocalUsers
+from noc.sa.interfaces.ihaslocaluser import IHasLocalUser
