@@ -175,7 +175,7 @@ class ManagedObject(models.Model):
                 rr.append("(sa_managedobject.administrative_domain_id=%s)")
                 pp.append(a.administrative_domain.id)
             if a.group:
-                rr.append("(id IN (SELECT managedobject_id FROM sa_managedobject_groups WHERE objectgroup_id=%s))")
+                rr.append("(sa_managedobject.id IN (SELECT managedobject_id FROM sa_managedobject_groups WHERE objectgroup_id=%s))")
                 pp.append(a.group.id)
             if len(rr)==1: # Single clause
                 r+=rr
@@ -276,6 +276,17 @@ class TaskSchedule(models.Model):
             TaskSchedule.objects.filter(next_run__lte=datetime.datetime.now(),is_enabled=True).exclude(id__in=exclude).order_by("-next_run")
         else:
             return TaskSchedule.objects.filter(next_run__lte=datetime.datetime.now(),is_enabled=True).order_by("-next_run")
+
+    ##
+    ## Link to relaunch task
+    ##
+    def run_now_link(self):
+        try:
+            return "<A HREF='/sa/task/%d/now/'>Run Now</A>"%(self.id)
+        except:
+            return ""
+    run_now_link.short_description="Run Now"
+    run_now_link.allow_tags=True
 ##
 ## Object Selector
 ##
@@ -356,6 +367,11 @@ class ManagedObjectSelector(models.Model):
             return ""
     test_link.short_description="Test Selector"
     test_link.allow_tags=True
+    ##
+    ## Check Managed Object matches selector
+    ##
+    def match(self,managed_object):
+        return self.managed_objects.filter(id=managed_object.id).count()>0
 ##
 ## Reduce Tasks
 ##
