@@ -11,14 +11,13 @@ import noc.sa.script
 from noc.sa.interfaces import IGetVersion
 import re
 
-rx_ver=re.compile(r"^Force10 Networks .*Force10 Application Software Version: (?P<version>\S+).*System Type: (?P<platform>\S+)",re.MULTILINE|re.DOTALL)
+rx_ver=re.compile(r"^Force10 Networks .*Force10 Application Software Version: (?P<version>\S+).*(?:System|Chassis) Type: (?P<platform>\S+)",re.MULTILINE|re.DOTALL)
 
 class Script(noc.sa.script.Script):
     name="Force10.FTOS.get_version"
     implements=[IGetVersion]
     def execute(self):
-        self.cli("terminal length 0")
-        v=self.cli("show version")
+        v=self.cli("show version | no-more")
         match=rx_ver.search(v)
         return {
             "vendor"    : "Force10",
