@@ -8,9 +8,10 @@
 """
 """
 from __future__ import with_statement
-from noc.sa.models import Activator, ManagedObject, TaskSchedule, MapTask
+from noc.sa.models import Activator, ManagedObject, TaskSchedule, MapTask, periodic_registry
 from noc.fm.models import Event,EventData,EventPriority,EventClass,EventCategory
 from noc.sa.rpc import RPCSocket,file_hash,get_digest,get_nonce
+from noc.pm.models import TimeSeries
 import logging,time,threading,datetime,os,random,xmlrpclib,cPickle
 from noc.sa.protocols.sae_pb2 import *
 from noc.lib.fileutils import read_file
@@ -129,17 +130,18 @@ class Service(SAEService):
             return
         activator=self.get_controller_activator(controller)
         try:
-            if request.ip=="":
-                # Event belongs to ROOT object
-                mo=ManagedObject.objects.get(name="ROOT")
-            else:
-                mo=ManagedObject.objects.get(activator=activator,trap_source_ip=request.ip)
+            mo=ManagedObject.objects.get(activator=activator,trap_source_ip=request.ip) if request.ip else None
         except ManagedObject.DoesNotExist:
             e=Error()
             e.code=ERR_UNKNOWN_EVENT_SOURCE
             e.text="Unknown event source '%s'"%request.ip
             done(controller,error=e)
             return
+        self.sae.write_event(
+            data=[(b.key,b.value) for b in request.body],
+            timestamp=datetime.datetime.fromtimestamp(request.timestamp),
+            managed_object=mo
+        )
         # Do all the magic here
         e=Event(
             timestamp=datetime.datetime.fromtimestamp(request.timestamp),
@@ -153,7 +155,32 @@ class Service(SAEService):
             d=EventData(event=e,key=b.key,value=b.value)
             d.save()
         done(controller,EventResponse())
-
+    ##
+    ## Performance management collected data stream
+    ##
+    def pm_data(self,controller,request,done):
+        if not controller.stream.is_authenticated:
+            e=Error()
+            e.code=ERR_AUTH_REQUIRED
+            e.text="Authentication required"
+            done(controller,error=e)
+            return
+        for d in request.result:
+            timestamp=datetime.datetime.fromtimestamp(d.timestamp)
+            self.sae.write_event([
+                    ("source",      "system"),
+                    ("type",        "pm probe"),
+                    ("probe_name",  d.probe_name),
+                    ("probe_type",  d.probe_type),
+                    ("service",     d.service),
+                    ("result",      d.result),
+                    ("message",     d.message),
+                ],
+                timestamp=timestamp)
+        for d in request.data:
+            value=d.value if not d.is_null else None
+            TimeSeries.register(d.name,d.timestamp,value)
+        done(controller,PMDataResponse())
 ##
 ## AcceptedTCPSocket with RPC Protocol
 ##
@@ -269,7 +296,17 @@ class SAE(Daemon):
         #
         self.activator_manifest=None
         self.activator_manifest_files=None
-    
+    ##
+    ## Create missed Task Schedules
+    ##
+    def update_task_schedules(self):
+        for pt in periodic_registry.classes:
+            if TaskSchedule.objects.filter(periodic_name=pt).count()==0:
+                logging.info("Creating task schedule for %s"%pt)
+                TaskSchedule(periodic_name=pt).save()
+    ##
+    ## Build activator manifest
+    ##
     def build_manifest(self):
         logging.info("Building manifest")
         manifest=read_file("MANIFEST-ACTIVATOR").split("\n")+ACTIVATOR_MANIFEST
@@ -323,6 +360,7 @@ class SAE(Daemon):
             self.xmlrpc_listener=self.factory.listen_tcp(xmlrpc_listen,xmlrpc_port,XMLRPCSocket)
         
     def run(self):
+        self.update_task_schedules()
         self.build_manifest()
         self.start_listeners()
         last_cleanup=time.time()
@@ -348,6 +386,26 @@ class SAE(Daemon):
                 self.process_mrtasks()
                 last_mrtask_check=time.time()
     ##
+    ## Write event.
+    ## data is a list of (left,right)
+    ##
+    def write_event(self,data,timestamp=None,managed_object=None):
+        if managed_object is None:
+            managed_object=ManagedObject.objects.get(name="ROOT")
+        if timestamp is None:
+            timestamp=datetime.datetime.now()
+        e=Event(
+            timestamp=timestamp,
+            event_priority=EventPriority.objects.get(name="DEFAULT"),
+            event_class=EventClass.objects.get(name="DEFAULT"),
+            event_category=EventCategory.objects.get(name="DEFAULT"),
+            managed_object=managed_object
+            )
+        e.save()
+        for l,r in data:
+            d=EventData(event=e,key=l,value=r)
+            d.save()
+    ##
     ## Collect crashinfo and write as FM events
     ##
     def collect_crashinfo(self):
@@ -356,10 +414,6 @@ class SAE(Daemon):
         c_d=os.path.dirname(self.config.get("main","logfile"))
         if not os.path.isdir(c_d):
             return
-        mo=ManagedObject.objects.get(name="ROOT")
-        event_priority=EventPriority.objects.get(name="DEFAULT")
-        event_class=EventClass.objects.get(name="DEFAULT")
-        event_category=EventCategory.objects.get(name="DEFAULT")
         for fn in [fn for fn in os.listdir(c_d) if fn.startswith(DEBUG_CTX_CRASH_PREFIX)]:
             path=os.path.join(c_d,fn)
             try:
@@ -370,19 +424,8 @@ class SAE(Daemon):
                 continue
             ts=data["ts"]
             del data["ts"]
-            e=Event(
-                timestamp=datetime.datetime.fromtimestamp(ts),
-                event_priority=event_priority,
-                event_class=event_class,
-                event_category=event_category,
-                managed_object=mo
-            )
-            e.save()
-            for k,v in data.items():
-                d=EventData(event=e,key=k,value=v)
-                d.save()
+            self.write_event(data=data.items(),timestamp=datetime.datetime.fromtimestamp(ts))
             os.unlink(path)
-            
     ##
     ## Periodic tasks
     ##
@@ -414,6 +457,14 @@ class SAE(Daemon):
             del self.active_periodic_tasks[task.id]
         finally:
             self.periodic_task_lock.release()
+        # Write task complete status event
+        self.write_event([
+            ("source","system"),
+            ("type",  "periodic status"),
+            ("task",  unicode(task)),
+            ("status",{True:"success",False:"failure"}[status]),
+        ])
+        #
         new_cwd=os.getcwd()
         if cwd!=new_cwd:
             logging.error("CWD changed by periodic '%s' ('%s' -> '%s'). Restoring old cwd"%(unicode(task),cwd,new_cwd))
@@ -499,28 +550,18 @@ class SAE(Daemon):
                     logging.error("Unknown object in ping_check: %s"%u)
                     return
                 mo=mo[0] # Fetch first-created object in case of multiple objects with same trap_source_ip
-                e=Event(
-                    timestamp=ts,
-                    event_priority=event_priority,
-                    event_class=event_class,
-                    event_category=event_category,
-                    managed_object=mo
-                    )
-                e.save()
-                for k,v in [("source","system"),
-                            ("activator",activator_name),
-                            ("probe","ping"),
-                            ("ip",u),
-                            ("result",result)]:
-                    d=EventData(event=e,key=k,value=v)
-                    d.save()
+                self.write_event(
+                    data=[("source","system"),
+                        ("activator",activator_name),
+                        ("probe","ping"),
+                        ("ip",u),
+                        ("result",result)],
+                    managed_object=mo,
+                    timestamp=ts)
             if error:
                 logging.error("ping_check failed: %s"%error.text)
                 return
             ts=datetime.datetime.now()
-            event_priority=EventPriority.objects.get(name="DEFAULT")
-            event_class=EventClass.objects.get(name="DEFAULT")
-            event_category=EventCategory.objects.get(name="DEFAULT")
             activator_name=activator.name
             for u in response.unreachable:
                 save_probe_result(u,"failed")
